/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.io.util;

import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;

class StructuredFileOperationsBundle
{

  /** Singleton instance. */
  private static final StructuredFileOperationsBundle instance =
    new StructuredFileOperationsBundle();

  /** Creates a new {@code StructuredFileOperationsBundle} instance. */
  StructuredFileOperationsBundle()
  {
    this.getMessage ( "alreadyClosed", Locale.getDefault() );
  }

  /**
   * Gets the {@code StructuredFileOperationsBundle} singleton.
   *
   * @return the {@code StructuredFileOperationsBundle} singleton.
   */
  static StructuredFileOperationsBundle getInstance()
  {
    return instance;
  }

  /**
   * Gets the text of the message with key {@code "alreadyClosed"}.
   *
   * @return <pre>
   * Instance is closed - cannot perform I/O.</pre>
   */
  String getAlreadyClosedText ( final Locale locale )
  {
    return this.getMessage ( "alreadyClosed", locale );
  }

  /**
   * Gets the message with key {@code "alreadyClosed"}.
   *
   * @return <pre>
   * Instance is closed - cannot perform I/O.</pre>
   */
  MessageFormat getAlreadyClosedMessage ( Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return new MessageFormat ( this.getMessage ( "alreadyClosed", locale ), locale );
  }

  /**
   * Gets a message for a given key and locale.
   *
   * @param key the key of the message to return.
   * @param locale the locale of the message.
   *
   * @return message for {@code key} using {@code locale}.
   */
  private String getMessage( final String key, Locale locale )
  {
    if ( locale == null )
    {
      locale = Locale.getDefault();
    }

    return ResourceBundle.getBundle( "org/jdtaus/core/io/util/StructuredFileOperations",
                                     locale ).getString( key );

  }
}
